#[non_exhaustive]pub struct NeighbourFlags(/* private fields */);Implementations
Sourceimpl NeighbourFlags
impl NeighbourFlags
pub const Use: NeighbourFlags
pub const Own: NeighbourFlags
pub const Controller: NeighbourFlags
pub const Proxy: NeighbourFlags
pub const ExtLearned: NeighbourFlags
pub const Offloaded: NeighbourFlags
pub const Sticky: NeighbourFlags
pub const Router: NeighbourFlags
Sourceimpl NeighbourFlags
impl NeighbourFlags
Sourcepub const fn empty() -> NeighbourFlags
pub const fn empty() -> NeighbourFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> NeighbourFlags
pub const fn all() -> NeighbourFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<NeighbourFlags>
pub const fn from_bits(bits: u8) -> Option<NeighbourFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> NeighbourFlags
pub const fn from_bits_truncate(bits: u8) -> NeighbourFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> NeighbourFlags
pub const fn from_bits_retain(bits: u8) -> NeighbourFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<NeighbourFlags>
pub fn from_name(name: &str) -> Option<NeighbourFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: NeighbourFlags) -> bool
pub const fn intersects(&self, other: NeighbourFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: NeighbourFlags) -> bool
pub const fn contains(&self, other: NeighbourFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: NeighbourFlags)
pub fn insert(&mut self, other: NeighbourFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: NeighbourFlags)
pub fn remove(&mut self, other: NeighbourFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: NeighbourFlags)
pub fn toggle(&mut self, other: NeighbourFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: NeighbourFlags, value: bool)
pub fn set(&mut self, other: NeighbourFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: NeighbourFlags) -> NeighbourFlags
pub const fn intersection(self, other: NeighbourFlags) -> NeighbourFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: NeighbourFlags) -> NeighbourFlags
pub const fn union(self, other: NeighbourFlags) -> NeighbourFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: NeighbourFlags) -> NeighbourFlags
pub const fn difference(self, other: NeighbourFlags) -> NeighbourFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: NeighbourFlags) -> NeighbourFlags
pub const fn symmetric_difference(self, other: NeighbourFlags) -> NeighbourFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> NeighbourFlags
pub const fn complement(self) -> NeighbourFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl NeighbourFlags
impl NeighbourFlags
Sourcepub const fn iter(&self) -> Iter<NeighbourFlags> ⓘ
pub const fn iter(&self) -> Iter<NeighbourFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<NeighbourFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<NeighbourFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.