#[non_exhaustive]pub struct RouteNextHopFlags(/* private fields */);Implementations
Sourceimpl RouteNextHopFlags
impl RouteNextHopFlags
pub const Dead: RouteNextHopFlags
pub const Pervasive: RouteNextHopFlags
pub const Onlink: RouteNextHopFlags
pub const Offload: RouteNextHopFlags
pub const Linkdown: RouteNextHopFlags
pub const Unresolved: RouteNextHopFlags
pub const Trap: RouteNextHopFlags
Sourceimpl RouteNextHopFlags
impl RouteNextHopFlags
Sourcepub const fn empty() -> RouteNextHopFlags
pub const fn empty() -> RouteNextHopFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> RouteNextHopFlags
pub const fn all() -> RouteNextHopFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<RouteNextHopFlags>
pub const fn from_bits(bits: u8) -> Option<RouteNextHopFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> RouteNextHopFlags
pub const fn from_bits_truncate(bits: u8) -> RouteNextHopFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> RouteNextHopFlags
pub const fn from_bits_retain(bits: u8) -> RouteNextHopFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RouteNextHopFlags>
pub fn from_name(name: &str) -> Option<RouteNextHopFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RouteNextHopFlags) -> bool
pub const fn intersects(&self, other: RouteNextHopFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: RouteNextHopFlags) -> bool
pub const fn contains(&self, other: RouteNextHopFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: RouteNextHopFlags)
pub fn insert(&mut self, other: RouteNextHopFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: RouteNextHopFlags)
pub fn remove(&mut self, other: RouteNextHopFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RouteNextHopFlags)
pub fn toggle(&mut self, other: RouteNextHopFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: RouteNextHopFlags, value: bool)
pub fn set(&mut self, other: RouteNextHopFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: RouteNextHopFlags) -> RouteNextHopFlags
pub const fn intersection(self, other: RouteNextHopFlags) -> RouteNextHopFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: RouteNextHopFlags) -> RouteNextHopFlags
pub const fn union(self, other: RouteNextHopFlags) -> RouteNextHopFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: RouteNextHopFlags) -> RouteNextHopFlags
pub const fn difference(self, other: RouteNextHopFlags) -> RouteNextHopFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: RouteNextHopFlags,
) -> RouteNextHopFlags
pub const fn symmetric_difference( self, other: RouteNextHopFlags, ) -> RouteNextHopFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> RouteNextHopFlags
pub const fn complement(self) -> RouteNextHopFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl RouteNextHopFlags
impl RouteNextHopFlags
Sourcepub const fn iter(&self) -> Iter<RouteNextHopFlags> ⓘ
pub const fn iter(&self) -> Iter<RouteNextHopFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RouteNextHopFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<RouteNextHopFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.